# pysorters
###  A Python package with all sort methods.
# Installation
### You can install the package via pip:
```bash
pip install pysorters
```
# Usage
```python
from pysorters import bubble_sort

bubble_sort([3, 2, 1])
# [1, 2, 3]
```
# License
### This project is licensed under the terms of the MIT license.
